@@ -1,13 +1,11 @@
 #include "cpl_port.h"
 #include "cpl_conv.h" // CPLFree()
 
-#include "gdal_utils.h" // requires 2.1
-
-#if GDAL_VERSION_MAJOR == 2 && GDAL_VERSION_MINOR < 1
-# error "Insufficient GDAL version, 2.1 required"
-#endif
+#if !(GDAL_VERSION_MAJOR == 2 && GDAL_VERSION_MINOR < 1)
+# include "gdal_utils.h" // requires >= 2.1
 
 #include "Rcpp.h"
+
 #define NO_GDAL_CPP_HEADERS
 #include "gdal_sf_pkg.h"
 
@@ -175,3 +173,51 @@ Rcpp::LogicalVector CPL_gdalgrid(Rcpp::CharacterVector src, Rcpp::CharacterVecto
 		GDALClose(result);
 	return result == NULL || err;
 }
+
+#else
+#include "Rcpp.h"
+
+Rcpp::CharacterVector CPL_gdalinfo(Rcpp::CharacterVector obj, Rcpp::CharacterVector options) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+
+Rcpp::LogicalVector CPL_gdalwarp(Rcpp::CharacterVector src, Rcpp::CharacterVector dst,
+		Rcpp::CharacterVector options) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+
+Rcpp::LogicalVector CPL_gdalrasterize(Rcpp::CharacterVector src, Rcpp::CharacterVector dst,
+		Rcpp::CharacterVector options) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+
+Rcpp::LogicalVector CPL_gdaltranslate(Rcpp::CharacterVector src, Rcpp::CharacterVector dst,
+		Rcpp::CharacterVector options) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+
+Rcpp::LogicalVector CPL_gdalvectortranslate(Rcpp::CharacterVector src, Rcpp::CharacterVector dst,
+		Rcpp::CharacterVector options) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+
+Rcpp::LogicalVector CPL_gdalbuildvrt(Rcpp::CharacterVector src, Rcpp::CharacterVector dst,
+		Rcpp::CharacterVector options) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+
+Rcpp::LogicalVector CPL_gdaldemprocessing(Rcpp::CharacterVector src, Rcpp::CharacterVector dst,
+		Rcpp::CharacterVector options, Rcpp::CharacterVector processing, Rcpp::CharacterVector colorfilename) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+
+Rcpp::LogicalVector CPL_gdalnearblack(Rcpp::CharacterVector src, Rcpp::CharacterVector dst,
+		Rcpp::CharacterVector options) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+
+Rcpp::LogicalVector CPL_gdalgrid(Rcpp::CharacterVector src, Rcpp::CharacterVector dst,
+		Rcpp::CharacterVector options) {
+	Rcpp::stop("GDAL version 2.1 required for gdal_utils");
+}
+#endif
